@@ -84,9 +84,6 @@ sub _CC_ {
     if (!$result) {
         print STDERR $stderr;
         print STDOUT $stdout;
-    } else {
-        no warnings;
-        print LOG $stdout;
     }
 }
 
@@ -96,9 +93,6 @@ sub _LD_ {
     if (!$result) {
         print STDERR $stderr;
         print STDOUT $stdout;
-    } else {
-        no warnings;
-        print LOG $stdout;
     }
 }
 
@@ -149,21 +143,7 @@ sub ACTION_install {
     # Run ldconfig if root
     if ($^O =~ /linux/ && $ENV{USER} eq 'root') {
         my $ldconfig = Config::AutoConf->check_prog("ldconfig");
-
-        my $libdir = $self->notes('libdir');
-
-        my $found = 0;
-        # 1. check if libdir is available
-        my $lines = `$ldconfig -v`;
-        for my $line (split /\n/, $lines) {
-            $found++ if $line =~ /^$libdir:/;
-        }
-        if (!$found && open X, ">>", '/etc/ld.so.conf') {
-            print X "$libdir\n";
-            close X;
-        }
-
-        system $ldconfig if -x $ldconfig;
+         system $ldconfig if -x $ldconfig;
     }
 }
 
@@ -399,9 +379,6 @@ sub _set_libbuilder {
     $libbuilder->{config}{lddlflags} =~ s/-arch \S+//g;
     $libbuilder->{config}{ldflags} =~ s/-arch \S+//g;
 
-    $libbuilder->{config}{lddlflags} =~ s{ -L\s*/usr/local/lib(?:$|\b)}{};
-    $libbuilder->{config}{ldflags} =~ s{ -L\s*/usr/local/lib(?:$|\b)}{};
-
     $self->notes(libbuilder => $libbuilder);
 }
 
